/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QTimer>

#include <csys/info_manager.h>

#include "wsystem.h"
#include "ui_wsystem.h"


wSystem::wSystem(QWidget *parent) : QWidget(parent), ui(new Ui::wSystem),
    info(InfoManager::ins())
{
    ui->setupUi(this);

    checkSystem();
    QTimer *timer = new QTimer();
    timer->start(1000);

    connect(timer, &QTimer::timeout, this, &wSystem::checkSystem);
}

wSystem::~wSystem()
{
    delete ui;
}

void wSystem::checkSystem()
{
    //set cpu value
    int cpuPercent = 0;
    QList<int> percentL = info->getCpuPercents();

    for (int i = 0; i < percentL.count(); i++) {
        cpuPercent += percentL.at(i);
    }

    int count = percentL.count() ? percentL.count() : 1;
    cpuPercent = cpuPercent / count;

    ui->cpu->setText("CPU " + QString::number(cpuPercent) + "% ");

    //set ram bar value
    info->updateMemoryInfo();
    int memPercent = 0;

    if (info->getMemTotal())
        memPercent = static_cast<int>((static_cast<double>(info->getMemUsed()) /
                                       static_cast<double>(info->getMemTotal())) * 100.0);

    ui->ram->setText("RAM " + QString::number(memPercent) + "%");
}

/* Name of the plugin */
QString systemplugin::name()
{
    return "System";
}

/* The plugin version */
QString systemplugin::version()
{
    return "2.7.0";
}

/* The Widget hooks for menus/toolbars */
QWidget *systemplugin::widget(QWidget *parent)
{
    return new wSystem(parent);
}
